pub enum NameTypeUnit<T> {
Local(DebugInfoOffset<T>),
Foreign(DebugTypeSignature),
}Expand description
A reference to a type unit.
This is the result of looking up a type unit index obtained from a DW_IDX_type_unit
attribute.
Variants
Local(DebugInfoOffset<T>)
The offset of a local type unit in the .debug_info section.
Foreign(DebugTypeSignature)
The type signature of a foreign type unit.