NameIndexHeader

Struct NameIndexHeader 

pub struct NameIndexHeader<R: Reader> { /* private fields */ }
The header of a name index in the .debug_names section.

Implementations

Source

impl<R: Reader> NameIndexHeader<R>

pub fn index(self) -> Result<NameIndex<R>>

Convert the header into a NameIndex.

pub fn offset(&self) -> DebugNamesOffset<R::Offset>

Return the section offset of this name index.

pub fn length(&self) -> R::Offset

Return the index length.

pub fn format(&self) -> Format

Return the format (DWARF32 or DWARF64).

pub fn version(&self) -> u16

Return the version of this name index.

pub fn compile_unit_count(&self) -> u32

Return the number of compilation units in this index.

pub fn local_type_unit_count(&self) -> u32

Return the number of local type units in this index.

pub fn foreign_type_unit_count(&self) -> u32

Return the number of foreign type units in this index.

pub fn bucket_count(&self) -> u32

Return the number of buckets in the hash table.

pub fn name_count(&self) -> u32

Return the number of unique name entries.

pub fn abbrev_table_size(&self) -> u32

Return the size of the abbreviations table in bytes.

pub fn augmentation_string(&self) -> Option<&R>

Return the augmentation string.