NameTableIndex

Struct NameTableIndex 

pub struct NameTableIndex(pub u32);
An index into the name table of a NameIndex.

This is used as an index into the list of string offsets, the list of entry offsets, and the list of hashes.

Note that while the DWARF standard specifies that indexes in the DWARF data start at 1, we use a zero based index here. Functions that read an index from the data will automatically adjust the index to start at 0.

Tuple Fields

0: u32