UnitOffset

Struct UnitOffset 

pub struct UnitOffset<T = usize>(pub T);
An offset into the current compilation or type unit.

Tuple Fields

0: T

Implementations

Source

impl<T: ReaderOffset> UnitOffset<T>

pub fn is_in_bounds<R>(&self, unit: &UnitHeader<R>) -> bool
where R: Reader<Offset = T>,

Return true if this offset is within the entries of the given unit.

This only checks that the offset is within the range of the data for unit entries, not that there is a valid DIE at this offset.

pub fn to_unit_section_offset<R>( &self, unit: &UnitHeader<R>, ) -> UnitSectionOffset<T>
where R: Reader<Offset = T>,

Convert an offset to be relative to the start of the section containing the unit, instead of relative to the start of the given unit.

Does not check that the offset is in bounds or valid. This is because often you will know that the offset came from this unit so it must be valid. For offsets of uncertain origin, use UnitOffset::is_in_bounds first.

pub fn to_debug_info_offset<R>( &self, unit: &UnitHeader<R>, ) -> Option<DebugInfoOffset<T>>
where R: Reader<Offset = T>,

Convert an offset to be relative to the start of the .debug_info section, instead of relative to the start of the given unit.

Returns None if the unit is not within the .debug_info section.

pub fn to_debug_types_offset<R>( &self, unit: &UnitHeader<R>, ) -> Option<DebugTypesOffset<T>>
where R: Reader<Offset = T>,

Convert an offset to be relative to the start of the .debug_types section, instead of relative to the start of the given unit.

Returns None if the unit is not within the .debug_types section.