pub struct NameIndexHeader<R: Reader> { /* private fields */ }Expand description
The header of a name index in the .debug_names section.
Implementations
Sourceimpl<R: Reader> NameIndexHeader<R>
impl<R: Reader> NameIndexHeader<R>
Sourcepub fn offset(&self) -> DebugNamesOffset<R::Offset>
pub fn offset(&self) -> DebugNamesOffset<R::Offset>
Return the section offset of this name index.
Sourcepub fn compile_unit_count(&self) -> u32
pub fn compile_unit_count(&self) -> u32
Return the number of compilation units in this index.
Sourcepub fn local_type_unit_count(&self) -> u32
pub fn local_type_unit_count(&self) -> u32
Return the number of local type units in this index.
Sourcepub fn foreign_type_unit_count(&self) -> u32
pub fn foreign_type_unit_count(&self) -> u32
Return the number of foreign type units in this index.
Sourcepub fn bucket_count(&self) -> u32
pub fn bucket_count(&self) -> u32
Return the number of buckets in the hash table.
Sourcepub fn name_count(&self) -> u32
pub fn name_count(&self) -> u32
Return the number of unique name entries.
Sourcepub fn abbrev_table_size(&self) -> u32
pub fn abbrev_table_size(&self) -> u32
Return the size of the abbreviations table in bytes.
Sourcepub fn augmentation_string(&self) -> Option<&R>
pub fn augmentation_string(&self) -> Option<&R>
Return the augmentation string.