pub struct NameTableIndex(pub u32);Expand description
An index into the name table of a NameIndex.
This is used as an index into the list of string offsets, the list of entry offsets, and the list of hashes.
Note that while the DWARF standard specifies that indexes in the DWARF data start at 1, we use a zero based index here. Functions that read an index from the data will automatically adjust the index to start at 0.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for NameTableIndex
impl Clone for NameTableIndex
Sourcefn clone(&self) -> NameTableIndex
fn clone(&self) -> NameTableIndex
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NameTableIndex
impl Debug for NameTableIndex
Sourceimpl PartialEq for NameTableIndex
impl PartialEq for NameTableIndex
impl Copy for NameTableIndex
impl Eq for NameTableIndex
impl StructuralPartialEq for NameTableIndex